
from django.contrib import admin

from .models import *
from .forms import *

#class SegmentTypeAdmin(admin.ModelAdmin):
#    model = SegmentType
#    list_display = ('Label','Syllabic','Obstruent','Nasal','Vowel')

#admin.site.register(SegmentType, SegmentTypeAdmin)

class LemmaAdmin(admin.ModelAdmin):
    model = Lemma
    list_display = ('Label','getSpellings')

admin.site.register(Lemma, LemmaAdmin)

class WordFormAdmin(admin.ModelAdmin):
    model = WordForm
    list_display = ('Lemma','getSpellings','getTranscriptions')

admin.site.register(WordForm, WordFormAdmin)
